# create Linux offline package
* install all dependencies
    * `make install` 
* run all tests
    * `make test`
* generate a Linux offline package
    * `make package`
* upload dist/\*_table_func_\*.tar.gz to yanhuang platform and register it